@@ -9,7 +9,7 @@ extern "C" {
 #include <stdlib.h>
 
 #define TERMKEY_VERSION_MAJOR 0
-#define TERMKEY_VERSION_MINOR 14
+#define TERMKEY_VERSION_MINOR 15
 
 #define TERMKEY_CHECK_VERSION \
         termkey_check_version(TERMKEY_VERSION_MAJOR, TERMKEY_VERSION_MINOR)
@@ -95,7 +95,8 @@ typedef enum {
   TERMKEY_TYPE_UNICODE,
   TERMKEY_TYPE_FUNCTION,
   TERMKEY_TYPE_KEYSYM,
-  TERMKEY_TYPE_MOUSE
+  TERMKEY_TYPE_MOUSE,
+  TERMKEY_TYPE_POSITION
 } TermKeyType;
 
 typedef enum {
@@ -199,6 +200,8 @@ TermKeySym termkey_keyname2sym(TermKey *tk, const char *keyname);
 
 TermKeyResult termkey_interpret_mouse(TermKey *tk, const TermKeyKey *key, TermKeyMouseEvent *event, int *button, int *line, int *col);
 
+TermKeyResult termkey_interpret_position(TermKey *tk, const TermKeyKey *key, int *line, int *col);
+
 typedef enum {
   TERMKEY_FORMAT_LONGMOD     = 1 << 0, /* Shift-... instead of S-... */
   TERMKEY_FORMAT_CARETCTRL   = 1 << 1, /* ^X instead of C-X */
